from setuptools import setup

setup(
    name = 'ssti-ab',
    version = '0.0.0',
    description = 'This is a dummy package.',
)

raise RuntimeError("This is a dummy package that was never ment to be actually installed. Please contact platform(at)kiwi.com.")
